/*****************************************************************************
 *
 * V4L2state.h -- V4L2 camera state header
 *
 * Copyright 2013,2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#ifndef OA_V4L2_STATE_H
#define OA_V4L2_STATE_H

#include <sys/types.h>
#include <linux/videodev2.h>
#include <linux/limits.h>

#define V4L2_BUFFERS 4

struct buffer {
  void   *start;
  size_t length;
};

typedef struct V4L2_STATE {
  char	         devicePath[ PATH_MAX+1];
  int            initialised;
  int            fd;
  int            exposureMode;
  float          exposureLength;
  uint32_t       exposureControl;
  int            haveAutoExposure;
  uint32_t       autoWhiteBalanceOff;
  uint32_t       haveWhiteBalanceManual;
  int            videoYUV420;
  int            videoRGB24;
  int            videoYUYV;
  int            videoGrey16;
  int            videoGrey;
  int            mosaicFormat;
  uint32_t       videoCurrent;
  // FIX ME -- ought to do this dynamically
  FRAMESIZE      resolutions[OA_MAX_RESOLUTIONS+1];
  // FIX ME -- only works for discrete rates?
  FRAMERATE      framerates[OA_MAX_FRAMERATES+1];
  struct buffer* buffers;
  int            configuredBuffers;
  int            lastUsedBuffer;
  int            bufferInUse;
  int            frameTime;
  int            colourDxK;
  int            isSPC900;
} V4L2_STATE;

#endif	/* OA_V4L2_STATE_H */
