/*****************************************************************************
 *
 * ZWASIstate.h -- ZW ASI camera state header
 *
 * Copyright 2013,2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#ifndef OA_ZWASI_STATE_H
#define OA_ZWASI_STATE_H

#define ZWASI_BUFFERS 1
  
struct ZWASIbuffer {  
  void   *start; 
  size_t length; 
};


typedef struct ZWASI_STATE {
  char	         devicePath[ PATH_MAX+1];
  int            initialised;
  int            index;
  int		 cameraType;
  uint32_t       currentBrightness;
  uint32_t       currentGain;
  uint32_t       currentAbsoluteExposure;
  uint32_t       currentGamma;
  uint32_t       currentRedBalance;
  uint32_t       currentBlueBalance;
  uint32_t       currentUSBTraffic;
  uint32_t       autoGain;
  uint32_t       autoBrightness;
  uint32_t       autoExposure;
  uint32_t       autoGamma;
  uint32_t       autoBlueBalance;
  uint32_t       autoRedBalance;
  uint32_t       autoUSBTraffic;
  uint32_t       currentHFlip;
  uint32_t       currentVFlip;
  uint32_t       currentBitDepth;
  int            videoRGB24;
  int            videoGrey16;
  int            videoGrey;
  int32_t        videoCurrent;
  uint32_t       next8BitMode;
  // FIX ME -- ought to do this dynamically
  FRAMESIZE      resolutions[OA_MAX_RESOLUTIONS+1];
  // FIX ME -- I'm going to use a magic number here because there are so few
  FRAMESIZE      binMode2Resolutions[4];
  FRAMESIZE      binMode3Resolutions[4];
  FRAMESIZE      binMode4Resolutions[4];
  int            frameRateSupport;
  int            binMode;
  int            xSize;
  int            ySize;
  struct ZWASIbuffer* buffers;
  int            configuredBuffers;
  int            lastUsedBuffer;
  int            bufferInUse;
  int            frameTime;
  int            imageBufferLength;
  uint32_t       maxResolutionX;
  uint32_t       maxResolutionY;

} ZWASI_STATE;

#endif	/* OA_ZWASI_STATE_H */
