/*****************************************************************************
 *
 * IIDCcapture.c -- capture functions for IIDC cameras
 *
 * Copyright 2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#include <oa_common.h>

#if HAVE_LIBDC1394

#include <openastro/oacam.h>

#include "IIDCoacam.h"

#define cameraState             camera->_iidc


int
oaIIDCCameraReadFrame ( oaCamera* camera, void** buffer )
{
  cameraState.currentFrame = 0;
  if ( dc1394_capture_dequeue ( cameraState.iidcHandle,
      DC1394_CAPTURE_POLICY_WAIT, &cameraState.currentFrame )
      == DC1394_SUCCESS ) {
    *buffer = cameraState.currentFrame->image;
    return cameraState.currentFrame->image_bytes;
  }
  return 0;
}

int
oaIIDCCameraStartReadFrame ( oaCamera* camera, unsigned int frameTime )
{
  return OA_ERR_NONE;
}


int
oaIIDCCameraFinishReadFrame ( oaCamera* camera )
{
  if ( cameraState.currentFrame ) {
    dc1394_capture_enqueue ( cameraState.iidcHandle, cameraState.currentFrame );
  }
  return OA_ERR_NONE;
}

#endif /* HAVE_LIBDC1394 */
