/*****************************************************************************
 *
 * IIDCoacam.c -- main entrypoint for IEE1394/IIDC Cameras
 *
 * Copyright 2013,2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#include <oa_common.h>

#if HAVE_LIBDC1394

#include <openastro/oacam.h>
#include <dc1394/dc1394.h>

#include "IIDCoacam.h"

#define	cameraState		camera->_iidc

/**
 * Cycle through the sys filesystem looking for USBdevices with one
 * of the appropriate vendor ID and product ID
 */

int
oaIIDCGetCameras ( oaDevice** deviceList )
{
  dc1394_t*	        iidcContext;
  dc1394error_t	        err;
  dc1394camera_list_t*  devlist;
  dc1394camera_t*       device;
  int                   numFound, current, i;
  uint8_t               unit;
  uint64_t              guid;
  oaDevice*             dev;

  current = 0;
  while ( deviceList[ current ] ) {
    current++;
  }
  if ( current >= OA_MAX_DEVICES ) {
    return 0;
  }

  iidcContext = dc1394_new();
  if ( !iidcContext ) {
    fprintf ( stderr, "Can't get IIDC context\n" );
    return -1;
  }
  err = dc1394_camera_enumerate ( iidcContext, &devlist );
  if ( err < 0 ) {
    dc1394_free ( iidcContext );
    fprintf ( stderr, "Can't enumerate IIDC devices\n" );
    return -1;
  }
  if ( !devlist->num ) {
    dc1394_camera_free_list ( devlist );
    dc1394_free ( iidcContext );
    return 0;
  }

  for ( i = 0; i < devlist->num; i++ ) {
    guid = devlist->ids[i].guid;
    unit = devlist->ids[i].unit;
    device = dc1394_camera_new_unit ( iidcContext, guid, unit );

    if (!( dev = malloc ( sizeof ( oaDevice )))) {
      dc1394_camera_free_list ( devlist );
      dc1394_free ( iidcContext );
      // FiX ME
      // set oaErrno
      return -1;
    }

    dev->interface = OA_IF_IIDC;
    ( void ) snprintf ( dev->deviceName, OA_MAX_NAME_LEN+1, "%s %s",
        device->vendor, device->model );
    dev->_guid = guid;
    dev->_unit = unit;
    dev->initCamera = oaIIDCInitCamera;
    dev->hasLoadableFirmware = oaIIDCDeviceHasLoadableFirmware;
    deviceList[ current++ ] = dev;
    numFound++;
    dc1394_camera_free ( device );
  }

  dc1394_camera_free_list ( devlist );
  dc1394_free ( iidcContext );
  return numFound;
}


int
oaIIDCCloseCamera ( oaCamera* camera )
{
  dc1394_camera_free ( cameraState.iidcHandle );
  cameraState.iidcHandle = 0;
  cameraState.initialised = 0;
  return 0;
}

#endif /* HAVE_LIBDC1394 */
