/*****************************************************************************
 *
 * IIDCoacam.h -- header for IEE1394/IIDC camera API
 *
 * Copyright 2013,2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#ifndef OA_IIDC_H
#define OA_IIDC_H

extern int		oaIIDCGetCameras ( oaDevice** );
extern oaCamera*	oaIIDCInitCamera ( oaDevice* );
extern int		oaIIDCCloseCamera ( oaCamera* );

extern int              oaIIDCCameraStart ( oaCamera*, START_PARMS* );
extern int              oaIIDCCameraStop ( oaCamera* );
extern int              oaIIDCCameraReset ( oaCamera* );

extern int              oaIIDCCameraHasLoadableFirmware ( oaCamera* );
extern int		oaIIDCDeviceHasLoadableFirmware ( oaDevice* );
extern int		oaIIDCCameraStartReadFrame ( oaCamera*, unsigned int );
extern int		oaIIDCCameraReadFrame ( oaCamera*, void** );
extern int		oaIIDCCameraFinishReadFrame ( oaCamera* );
extern int		oaIIDCCameraGetControlRange ( oaCamera*, int,
				int*, int*, int*, int* );
extern const FRAMESIZE*	oaIIDCCameraGetFrameSizes ( oaCamera* );
extern const FRAMERATE*	oaIIDCCameraGetFrameRates ( oaCamera*, int, int );
extern int		oaIIDCCameraHasFixedFrameRates ( oaCamera*, int, int );

extern const char*	oaIIDCCameraGetName ( oaCamera* );
extern int		oaIIDCCameraGetFramePixelFormat ( oaCamera*, int );

extern int		oaIIDCCameraTestControl ( oaCamera*, int, int );
extern int		oaIIDCCameraSetControl ( oaCamera*, int, int );
extern int		oaIIDCCameraReadControl ( oaCamera*, int );
/*
extern int		oaIIDCCameraSetROI ( oaCamera*, int, int );
extern int		oaIIDCCameraSetFrameInterval ( oaCamera*, int, int );
extern int		oaIIDCCameraTestROISize ( oaCamera*, int, int,
				int*, int* );
extern const char*	oaIIDCCameraGetMenuString ( oaCamera*, int, int );
*/

struct iidcCtrl {
  int  iidcControl;
  int  oaControl;
  int  oaAutoControl;
};

extern struct iidcCtrl dc1394Controls[];
extern unsigned int numIIDCControls;

struct iidcFrameRate {
  int iidcFrameRate;
  int numerator;
  int denominator;
};

extern struct iidcFrameRate dc1394FrameRates[];
extern unsigned int numIIDCFrameRates;

#define NUM_IIDC_BUFFERS        5

#endif	/* OA_IIDC_H */
