/*****************************************************************************
 *
 * UVCgetFeatures.c -- feature enumeration for UVC cameras
 *
 * Copyright 2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#include <oa_common.h>
#include <openastro/oacam.h>

#include "UVCoacam.h"

#define	cameraState	camera->_uvc


/**
 * Check if a camera has fixed frame rates
 */

int
oaUVCCameraHasFixedFrameRates ( oaCamera* camera, int resX, int resY )
{
  uvc_frame_desc_t* frame;

  frame = cameraState.videoCurrent->frame_descs;
  do {
    if ( frame->wWidth == resX && frame->wHeight == resY ) {
      break;
    }
    frame = frame->next;
  } while ( frame );

  if ( !frame ) {
    return 0;
  }

  return ( frame->bFrameIntervalType > 1 ) ? 1 : 0;
}


int
oaUVCCameraStartRequiresROI ( oaCamera* camera )
{
  return 1;
}


int
oaUVCCameraHasLoadableFirmware ( oaCamera* camera )
{
  return 0;
}


int
oaUVCDeviceHasLoadableFirmware ( oaDevice* device )
{
  return 0;
}
