/*****************************************************************************
 *
 * UVCgetState.c -- state querying for UVC cameras
 *
 * Copyright 2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#include <oa_common.h>

#if HAVE_LIBUVC

#include <openastro/oacam.h>

#include "UVCoacam.h"
#include "oacamprivate.h"

#define	cameraState		camera->_uvc

int
oaUVCCameraGetControlRange ( oaCamera* camera, int control, int* min,
    int* max, int* step, int* def )
{
  *min = camera->min [ control ];
  *max = camera->max [ control ];
  *step = camera->step [ control ];
  *def = camera->def [ control ];
  return 0;
}


const FRAMESIZE*
oaUVCCameraGetFrameSizes ( oaCamera* camera )
{
  return cameraState.resolutions;
}


const FRAMERATE*
oaUVCCameraGetFrameRates ( oaCamera* camera, int resX, int resY )
{
  uvc_frame_desc_t* frame;
  uint32_t* interval;
  int i;

  frame = cameraState.videoCurrent->frame_descs;
  do {
    if ( frame->wWidth == resX && frame->wHeight == resY ) {
      break;
    }
    frame = frame->next;
  } while ( frame );

  if ( !frame ) {
    return 0;
  }

  OA_CLEAR ( cameraState.framerates );
  i = 0;
  interval = frame->intervals;
  while ( interval && *interval ) {
    // interval units are 100ns
    cameraState.framerates[i].numerator = 1;
    cameraState.framerates[i].denominator = ( int ) 10000000 / *interval;
    i++;
    interval++;
  }

  cameraState.framerates[i].numerator = 0;
  cameraState.framerates[i].denominator = 0;

  return cameraState.framerates;
}


const char*
oaUVCCameraGetName ( oaCamera* camera )
{
  return camera->deviceName;
}


int
oaUVCCameraGetFramePixelFormat ( oaCamera* camera, int depth )
{
  if ( !memcmp ( cameraState.videoCurrent->fourccFormat, "BY8 ", 4 )) {
    // FIX ME -- may not be at all, of course
    return OA_PIX_FMT_GBRG8;
  }

  if ( !memcmp ( cameraState.videoCurrent->fourccFormat, "Y800", 4 )) {
    return OA_PIX_FMT_GREY8;
  }

  fprintf ( stderr, "%s can't handle pixel format %16s\n", __FUNCTION__,
      cameraState.videoCurrent->guidFormat );
  return OA_PIX_FMT_RGB24;
}

#endif /* HAVE_LIBUVC */
