/*****************************************************************************
 *
 * UVCoacam.c -- main entrypoint for UVC Cameras
 *
 * Copyright 2013,2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#include <oa_common.h>

#if HAVE_LIBUVC

#include <openastro/oacam.h>
#include <libuvc/libuvc.h>

#include "UVCoacam.h"
#include "unimplemented.h"


int
oaUVCGetCameras ( oaDevice** deviceList )
{
  unsigned int				numFound = 0, current = 0;
  unsigned int				numUVCDevices = 0, i;
  unsigned int  		        index;
  unsigned short			busNum, addr;
  uvc_context_t*			ctx;
  uvc_device_t**      		 	devlist;
  uvc_device_t*      		 	device;
  uvc_device_descriptor_t*		desc;
  oaDevice*				dev;

  while ( deviceList[ current ] ) {
    current++;
  }
  if ( current >= OA_MAX_DEVICES ) {
    return 0;
  }

  if ( uvc_init ( &ctx, 0 ) != UVC_SUCCESS ) {
    fprintf ( stderr, "uvc_init failed\n" );
    return 0;
  }

  if ( uvc_get_device_list ( ctx, &devlist ) != UVC_SUCCESS ) {
    fprintf ( stderr, "uvc_get_device_list failed\n" );
    return 0;
  }
  while ( devlist[numUVCDevices] ) { numUVCDevices++; }
  if ( numUVCDevices < 1 ) {
    uvc_free_device_list ( devlist, 1 );
    uvc_exit ( ctx );
    return 0;
  }

  for ( i = 0; i < numUVCDevices; i++ ) {
    device = devlist[i];
    if ( uvc_get_device_descriptor ( device, &desc )) {
      uvc_free_device_list ( devlist, 1 );
      uvc_exit ( ctx );
      return -1;
    }
    busNum = uvc_get_bus_number ( device );
    addr = uvc_get_device_address ( device );
    index = ( busNum << 8 ) | addr;

    fprintf ( stderr, "found %s %s camera at %d, %d\n", desc->manufacturer ? desc->manufacturer : "unknown", desc->product ? desc->product: "unknown", busNum, addr );
    // now we can drop the data into the list
    if (!( dev = malloc ( sizeof ( oaDevice )))) {
      uvc_free_device_descriptor ( desc );
      uvc_free_device_list ( devlist, 1 );
      uvc_exit ( ctx );
      // FiX ME
      // set oaErrno
      return -1;
    }

    _oaInitDeviceFunctionPointers ( dev );
    dev->interface = OA_IF_UVC;
    dev->_devIndex = index;
    if ( desc->product ) {
      ( void ) strcpy ( dev->deviceName, desc->product );
    } else {
      ( void ) snprintf ( dev->deviceName, OA_MAX_NAME_LEN+1,
          "UVC camera @ USB %d:%d", busNum, addr );
    }
    // dev->_vendorId = desc->vendorId;
    // dev->_productId = desc->productId;
    dev->initCamera = oaUVCInitCamera;
    dev->hasLoadableFirmware = oaUVCDeviceHasLoadableFirmware;
    deviceList[ current++ ] = dev;
    numFound++;

    uvc_free_device_descriptor ( desc );
  }

  uvc_free_device_list ( devlist, 1 );
  uvc_exit ( ctx );
  return numFound;
}

#endif	/* HAVE_LIBUVC */
