/*****************************************************************************
 *
 * UVCoacam.h -- header for UVC camera API
 *
 * Copyright 2013,2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#ifndef OA_UVC_H
#define OA_UVC_H

extern int		oaUVCGetCameras ( oaDevice** );
extern oaCamera*	oaUVCInitCamera ( oaDevice* );
extern int              oaUVCCloseCamera ( oaCamera* );

extern int              oaUVCCameraStart ( oaCamera*, START_PARMS* );
extern int              oaUVCCameraStop ( oaCamera* );
extern int              oaUVCCameraReset ( oaCamera* );

extern int              oaUVCCameraHasLoadableFirmware ( oaCamera* );
extern int		oaUVCDeviceHasLoadableFirmware ( oaDevice* );

extern int		oaUVCCameraStartReadFrame ( oaCamera*, unsigned int );
extern int		oaUVCCameraReadFrame ( oaCamera*, void** );
extern int		oaUVCCameraFinishReadFrame ( oaCamera* );

extern int		oaUVCCameraGetControlRange ( oaCamera*, int,
				int*, int*, int*, int* );
extern const FRAMESIZE*	oaUVCCameraGetFrameSizes ( oaCamera* );
extern const FRAMERATE*	oaUVCCameraGetFrameRates ( oaCamera*, int, int );
extern int		oaUVCCameraHasFixedFrameRates ( oaCamera*, int, int );
extern const char*	oaUVCCameraGetName ( oaCamera* );
extern int		oaUVCCameraGetFramePixelFormat ( oaCamera*, int );

extern int		oaUVCCameraTestControl ( oaCamera*, int, int );
extern int		oaUVCCameraSetControl ( oaCamera*, int, int );
extern int		oaUVCCameraReadControl ( oaCamera*, int );
/*
extern int		oaUVCCameraSetROI ( oaCamera*, int, int );
extern int		oaUVCCameraSetFrameInterval ( oaCamera*, int, int );
extern int		oaUVCCameraTestROISize ( oaCamera*, int, int,
				int*, int* );
*/
extern const char*	oaUVCCameraGetMenuString ( oaCamera*, int, int );

extern int		getUVCControl ( uvc_device_handle_t*, uint8_t,
			    enum uvc_ct_ctrl_selector, int, enum uvc_req_code );
extern int		setUVCControl ( uvc_device_handle_t*, uint8_t,
			    enum uvc_ct_ctrl_selector, int, int );
extern void		frameCallback ( uvc_frame_t*, void* );


struct puCtrl {
  enum uvc_pu_ctrl_selector	uvcControl;
  int				oaControl;
  int				oaControlType;
  int				size;
};

extern struct puCtrl controlData[];
extern unsigned int numPUControls;

// All the GUIDs

#define UVC_GUID_FORMAT_MJPEG \
        { 'M',  'J',  'P',  'G', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_YUY2 \
        { 'Y',  'U',  'Y',  '2', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_YUY2_ISIGHT \
        { 'Y',  'U',  'Y',  '2', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0x00, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_NV12 \
        { 'N',  'V',  '1',  '2', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_YV12 \
        { 'Y',  'V',  '1',  '2', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_I420 \
        { 'I',  '4',  '2',  '0', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_UYVY \
        { 'U',  'Y',  'V',  'Y', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_Y800 \
        { 'Y',  '8',  '0',  '0', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_Y8 \
        { 'Y',  '8',  ' ',  ' ', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_Y10 \
        { 'Y',  '1',  '0',  ' ', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_Y12 \
        { 'Y',  '1',  '2',  ' ', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_Y16 \
        { 'Y',  '1',  '6',  ' ', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_BY8 \
        { 'B',  'Y',  '8',  ' ', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_RGBP \
        { 'R',  'G',  'B',  'P', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_M420 \
        { 'M',  '4',  '2',  '0', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}
#define UVC_GUID_FORMAT_H264 \
        { 'H',  '2',  '6',  '4', 0x00, 0x00, 0x10, 0x00, \
         0x80, 0x00, 0x00, 0xaa, 0x00, 0x38, 0x9b, 0x71}

#endif	/* OA_UVC_H */
