/*****************************************************************************
 *
 * ZWASIgetState.c -- state querying for ZW ASI cameras
 *
 * Copyright 2013,2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#include <oa_common.h>
#include <openastro/oacam.h>

#include <ASICamera.h>

#include "ZWASIoacam.h"

#define	cameraState		camera->_zwasi


int
oaZWASICameraGetControlRange ( oaCamera* camera, int control, int* min,
    int* max, int* step, int* def )
{
  if ( !camera->controls[ control ] ) {
    return -OA_ERR_INVALID_CONTROL;
  }

  *min = camera->min[ control ];
  *max = camera->max[ control ];
  *step = camera->step[ control ];
  *def = camera->def[ control ];
  return 0;
}


const FRAMESIZE*
oaZWASICameraGetFrameSizes ( oaCamera* camera )
{
  switch ( cameraState.binMode ) {
    case OA_BIN_MODE_NONE:
      return cameraState.resolutions;
      break;
    case OA_BIN_MODE_2x2:
      return cameraState.binMode2Resolutions;
      break;
    case OA_BIN_MODE_3x3:
      return cameraState.binMode3Resolutions;
      break;
    case OA_BIN_MODE_4x4:
      return cameraState.binMode4Resolutions;
      break;
  }
  fprintf ( stderr, "oaZWASICameraGetFrameSizes: unknown bin mode %d\n",
      cameraState.binMode );
  return 0;
}


const char*
oaZWASICameraGetName ( oaCamera* camera )
{
  return camera->deviceName;
}


int
oaZWASICameraGetFramePixelFormat ( oaCamera *camera, int depth )
{
  if ( depth <= 0 ) {
    switch ( cameraState.videoCurrent ) {
      case IMG_RGB24:
        return OA_PIX_FMT_BGR24;
        break;
      case IMG_RAW16:
        if ( isColorCam()) {
          return OA_PIX_FMT_GRBG16LE;
        }
        return OA_PIX_FMT_GREY16LE;
        break;
      case IMG_RAW8:
        if ( isColorCam()) {
          return OA_PIX_FMT_GRBG8;
        } else {
          return OA_PIX_FMT_GREY8;
        }
        break;
      case IMG_Y8:
        // I believe the colour camera returns this as a monochrome RGB
        // image
        if ( isColorCam()) {
          return OA_PIX_FMT_BGR24;
        } else {
          return OA_PIX_FMT_GREY8;
        }
        break;
    }
  } else {
    if ( 12 == depth || 16 == depth ) {
      if ( isColorCam()) {
        return OA_PIX_FMT_GRBG16LE;
      }
      return OA_PIX_FMT_GREY16LE;
    }
    if ( 8 == depth ) {
      if ( isColorCam()) {
        if ( cameraState.videoCurrent == IMG_RAW8 ||
            cameraState.videoCurrent == IMG_RAW16 ) {
          return OA_PIX_FMT_GRBG8;
        } else {
          return OA_PIX_FMT_BGR24;
        }
      }
      return OA_PIX_FMT_GREY8;
    }
  }

  // default
  return OA_PIX_FMT_BGR24;
}
