/*****************************************************************************
 *
 * ZWASIoacam.h -- header for ZW ASI camera API
 *
 * Copyright 2013,2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#ifndef OA_ZWASI_H
#define OA_ZWASI_H

extern int		oaZWASIGetCameras ( oaDevice** );
extern oaCamera*	oaZWASIInitCamera ( oaDevice* );
extern int              oaZWASICloseCamera ( oaCamera* );
extern int              oaZWASICameraStart ( oaCamera*, START_PARMS* );
extern int              oaZWASICameraStop ( oaCamera* );
extern int              oaZWASICameraReset ( oaCamera* );

extern int              oaZWASICameraHasLoadableFirmware ( oaCamera* );
extern int		oaZWASIDeviceHasLoadableFirmware ( oaDevice* );

extern int		oaZWASICameraStartReadFrame ( oaCamera*, unsigned int );
extern int		oaZWASICameraReadFrame ( oaCamera*, void** );
extern int		oaZWASICameraFinishReadFrame ( oaCamera* );

extern int		oaZWASICameraGetControlRange ( oaCamera*, int,
				int*, int*, int*, int* );
extern const FRAMESIZE*	oaZWASICameraGetFrameSizes ( oaCamera* );
extern const FRAMERATE*	oaZWASICameraGetFrameRates ( oaCamera*, int, int );
extern const char*	oaZWASICameraGetName ( oaCamera* );
extern int		oaZWASICameraGetFramePixelFormat ( oaCamera*, int );


extern int		oaZWASICameraSetControl ( oaCamera*, int, int );
extern int		oaZWASICameraTestControl ( oaCamera*, int, int );
extern int		oaZWASICameraReadControl ( oaCamera*, int );

extern int		oaZWASICameraSetROI ( oaCamera*, int, int );
extern int		oaZWASICameraSetFrameInterval ( oaCamera*, int, int );
extern int		oaZWASICameraTestROISize ( oaCamera*, int, int,
				int*, int* );

#define	ZWOCAM_UNKNOWN	-1
#define	ZWOCAM_ASI130MM	0
#define ZWOCAM_ASI120MM	1
#define ZWOCAM_ASI120MC	2
#define ZWOCAM_ASI035MM	3
#define ZWOCAM_ASI035MC	4
#define ZWOCAM_ASI030MC	5
#define ZWOCAM_ASI034MC	6
#define ZWO_NUM_CAMERAS	7

#endif	/* OA_ZWASI_H */
