/*****************************************************************************
 *
 * ZWASIroi.c -- region of interest management for ZW ASI cameras
 *
 * Copyright 2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#include <oa_common.h>
#include <openastro/oacam.h>
#include <openastro/errno.h>

#include <ASICamera.h>

#include "ZWASIoacam.h"

#define	cameraState		camera->_zwasi


int
oaZWASICameraTestROISize ( oaCamera* camera, int tryX, int tryY,
    int* suggX, int* suggY )
{
  int n, done;

  if ( tryX > 0 && tryY > 0 && ( tryX * tryY ) % 1024 == 0 ) {
    if (( tryX * cameraState.binMode ) <= cameraState.resolutions[0].x &&
        ( tryY * cameraState.binMode ) <= cameraState.resolutions[0].y ) {
      return OA_ERR_NONE;
    }
  }

  n = done = 0;
  while ( !done && cameraState.resolutions[ n ].x ) {
    if ( cameraState.resolutions[ n ].x <= tryX ) {
      done = 1;
    } else {
      n++;
    }
  }
  if ( !done ) {
    n--;
  }

  *suggX = cameraState.resolutions[ n ].x;
  *suggY = cameraState.resolutions[ n ].y;

  return -OA_ERR_INVALID_SIZE;
}
