/*****************************************************************************
 *
 * oacam.c -- main camera library entrypoint
 *
 * Copyright 2013,2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#include <oa_common.h>
#include <openastro/oacam.h>

#if HAVE_LIBV4L2
#include "V4L2oacam.h"
#endif
#if HAVE_LIBDC1394
#include "IIDCoacam.h"
#endif
#include "PWCoacam.h"
#include "ZWASIoacam.h"
#include "QHYoacam.h"
#if HAVE_LIBUVC
#include "UVCoacam.h"
#endif
#include "oacamversion.h"
#include "oacamprivate.h"

static int      (*getFunctions[])() = {
#ifdef	OA_PWC_DRIVER_SUPPORT
   oaPWCGetCameras,
#endif
   oaZWASIGetCameras,
   oaQHYGetCameras,
#if HAVE_LIBDC1394
   oaIIDCGetCameras,
#endif
#if HAVE_LIBV4L2
   oaV4L2GetCameras,
#endif
#if HAVE_LIBUVC
   oaUVCGetCameras,
#endif
   0,
   0
};
  

char*	installPathRoot = 0;

int
oaGetCameras( oaDevice** deviceList )
{
  int           i = 0, n, numDevices = 0;

  while ( getFunctions[i] ) {
    // FIX ME
    // error on found < 0 ?
    n = getFunctions[i]( deviceList );
    numDevices += n;
    i++;
  }

  return numDevices;
}


unsigned int
oaGetCameraAPIVersion ( void )
{
  unsigned int v;

  v = ( OACAM_MAJOR_VERSION << 16 ) + ( OACAM_MINOR_VERSION << 8 ) +
      OACAM_REVISION;
  return v;
}


const char*
oaGetCameraAPIVersionStr ( void )
{
  static char vs[ 40 ];

  snprintf ( vs, 40, "%d.%d.%d", OACAM_MAJOR_VERSION, OACAM_MINOR_VERSION,
      OACAM_REVISION );
  return vs;
}


void
oaSetCameraDebugLevel ( int v )
{
  oacamSetDebugLevel ( v );
}
