/*****************************************************************************
 *
 * config.h -- declaration of data structures for configuration data
 *
 * Copyright 2013,2014 James Fidell (james@openastroproject.org)
 *
 * License:
 *
 * This file is part of the Open Astro Project.
 *
 * The Open Astro Project is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Open Astro Project is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Open Astro Project.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 *****************************************************************************/

#pragma once

extern "C" {
#include <openastro/oacam.h>
}

#define	CONFIG_VERSION	3

typedef struct {
  QString       profileName;
  int           sixteenBit;
  int           binning2x2;
  int           rawMode;
  int           useROI;
  int           imageSizeX;
  int           imageSizeY;
  int           controls[ OA_CAM_CTRL_LAST_P1 ];
  int           frameRateNumerator;
  int           frameRateDenominator;
  int           fileTypeOption;
  int           filterOption;
  int           limitEnabled;
  int           secondsLimitValue;
  int           framesLimitValue;
  int           limitType;
  QString       fileNameTemplate;
} PROFILE;


// overkill, but i may want to expand this later
typedef struct {
  QString	filterName;
} FILTER;


typedef struct
{
  // general
  int			saveSettings;
  int			tempsInC;
  int			connectSoleCamera;

  // settings from device menu
  int			cameraDevice;

  // options menu
  int			showHistogram;
  int			autoAlign;
  int			alignBox;
  int			autoGuide;
  int			showReticle;
  int			cutout;
  int			focusAid;
  int			darkFrame;
  int			derotate;
  int			flipX;
  int			flipY;
  int			demosaic;

  // camera config
  int			sixteenBit;
  int			binning2x2;
  int			rawMode;

  // image config
  int			useROI;
  int			imageSizeX;
  int			imageSizeY;

  // zoom config
  int			zoomButton1Option;
  int			zoomButton2Option;
  int			zoomButton3Option;
  int			zoomValue;

  // control config
  int			controlValues[ OA_CAM_CTRL_LAST_P1 ];
  int			exposureMenuOption;
  int			frameRateNumerator;
  int			frameRateDenominator;
  int			selectableControl[2];

  // capture config
  int			profileOption;
  int			filterOption;
  int			fileTypeOption;
  int			limitEnabled;
  int			secondsLimitValue;
  int			framesLimitValue;
  int			limitType;
  QString		fileNameTemplate;
  QString		captureDirectory;
  int			autorunCount;
  int			autorunDelay;
  int			saveCaptureSettings;

  // display config
  int			preview;
  int			nightMode;
  int			displayFPS;

  // reticle config
  int			reticleStyle;

  // histogram config
  int			splitHistogram;
  int			histogramOnTop;

  // demosaic config
  int			demosaicPreview;
  int			demosaicOutput;
  int			cfaPattern;
  int			demosaicMethod;

  // saved profiles
  int			numProfiles;
  QList<PROFILE>	profiles;

  // saved profiles
  int			numFilters;
  QList<FILTER>		filters;
} CONFIG;

extern CONFIG		config;
